# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKFastMarchingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _ITKFastMarchingBasePython
else:
    import _ITKFastMarchingBasePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkLevelSetNodePython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.pyBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.itkFixedArrayPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkNodePairPython
import itk.itkFastMarchingStoppingCriterionBasePython
class itkFastMarchingBaseIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkFastMarchingBaseIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetTopologyCheck(self, _arg):
        r"""
        SetTopologyCheck(self, _arg)

        Parameters
        ----------
        _arg: enum itkFastMarchingTraitsEnums::TopologyCheck const

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_SetTopologyCheck(self, _arg)

    def GetTopologyCheck(self):
        r"""GetTopologyCheck(self) -> itkFastMarchingTraitsEnums::TopologyCheck const &"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetTopologyCheck(self)

    def SetTrialPoints(self, _arg):
        r"""
        SetTrialPoints(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerULNPI2F *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_SetTrialPoints(self, _arg)

    def GetModifiableTrialPoints(self):
        r"""GetModifiableTrialPoints(self) -> itkVectorContainerULNPI2F"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetModifiableTrialPoints(self)

    def GetTrialPoints(self, *args):
        r"""
        GetTrialPoints(self) -> itkVectorContainerULNPI2F
        GetTrialPoints(self) -> itkVectorContainerULNPI2F
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetTrialPoints(self, *args)

    def SetAlivePoints(self, _arg):
        r"""
        SetAlivePoints(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerULNPI2F *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_SetAlivePoints(self, _arg)

    def GetModifiableAlivePoints(self):
        r"""GetModifiableAlivePoints(self) -> itkVectorContainerULNPI2F"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetModifiableAlivePoints(self)

    def GetAlivePoints(self, *args):
        r"""
        GetAlivePoints(self) -> itkVectorContainerULNPI2F
        GetAlivePoints(self) -> itkVectorContainerULNPI2F
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetAlivePoints(self, *args)

    def SetProcessedPoints(self, _arg):
        r"""
        SetProcessedPoints(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerULNPI2F *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_SetProcessedPoints(self, _arg)

    def GetModifiableProcessedPoints(self):
        r"""GetModifiableProcessedPoints(self) -> itkVectorContainerULNPI2F"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetModifiableProcessedPoints(self)

    def GetProcessedPoints(self, *args):
        r"""
        GetProcessedPoints(self) -> itkVectorContainerULNPI2F
        GetProcessedPoints(self) -> itkVectorContainerULNPI2F
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetProcessedPoints(self, *args)

    def SetForbiddenPoints(self, _arg):
        r"""
        SetForbiddenPoints(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerULNPI2F *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_SetForbiddenPoints(self, _arg)

    def GetModifiableForbiddenPoints(self):
        r"""GetModifiableForbiddenPoints(self) -> itkVectorContainerULNPI2F"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetModifiableForbiddenPoints(self)

    def GetForbiddenPoints(self, *args):
        r"""
        GetForbiddenPoints(self) -> itkVectorContainerULNPI2F
        GetForbiddenPoints(self) -> itkVectorContainerULNPI2F
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetForbiddenPoints(self, *args)

    def SetStoppingCriterion(self, _arg):
        r"""
        SetStoppingCriterion(self, _arg)

        Parameters
        ----------
        _arg: itkFastMarchingStoppingCriterionBaseIF2IF2 *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_SetStoppingCriterion(self, _arg)

    def GetModifiableStoppingCriterion(self):
        r"""GetModifiableStoppingCriterion(self) -> itkFastMarchingStoppingCriterionBaseIF2IF2"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetModifiableStoppingCriterion(self)

    def GetStoppingCriterion(self, *args):
        r"""
        GetStoppingCriterion(self) -> itkFastMarchingStoppingCriterionBaseIF2IF2
        GetStoppingCriterion(self) -> itkFastMarchingStoppingCriterionBaseIF2IF2
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetStoppingCriterion(self, *args)

    def GetSpeedConstant(self):
        r"""GetSpeedConstant(self) -> double"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetSpeedConstant(self)

    def SetSpeedConstant(self, _arg):
        r"""
        SetSpeedConstant(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_SetSpeedConstant(self, _arg)

    def GetNormalizationFactor(self):
        r"""GetNormalizationFactor(self) -> double"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetNormalizationFactor(self)

    def SetNormalizationFactor(self, _arg):
        r"""
        SetNormalizationFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_SetNormalizationFactor(self, _arg)

    def GetTargetReachedValue(self):
        r"""GetTargetReachedValue(self) -> float"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetTargetReachedValue(self)

    def SetCollectPoints(self, _arg):
        r"""
        SetCollectPoints(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_SetCollectPoints(self, _arg)

    def GetCollectPoints(self):
        r"""GetCollectPoints(self) -> bool const &"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_GetCollectPoints(self)

    def CollectPointsOn(self):
        r"""CollectPointsOn(self)"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_CollectPointsOn(self)

    def CollectPointsOff(self):
        r"""CollectPointsOff(self)"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_CollectPointsOff(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkFastMarchingBaseIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingBaseIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_cast(obj)

# Register itkFastMarchingBaseIF2IF2 in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2_swigregister(itkFastMarchingBaseIF2IF2)
class itkFastMarchingBaseIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkFastMarchingBaseIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetTopologyCheck(self, _arg):
        r"""
        SetTopologyCheck(self, _arg)

        Parameters
        ----------
        _arg: enum itkFastMarchingTraitsEnums::TopologyCheck const

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_SetTopologyCheck(self, _arg)

    def GetTopologyCheck(self):
        r"""GetTopologyCheck(self) -> itkFastMarchingTraitsEnums::TopologyCheck const &"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetTopologyCheck(self)

    def SetTrialPoints(self, _arg):
        r"""
        SetTrialPoints(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerULNPI3F *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_SetTrialPoints(self, _arg)

    def GetModifiableTrialPoints(self):
        r"""GetModifiableTrialPoints(self) -> itkVectorContainerULNPI3F"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetModifiableTrialPoints(self)

    def GetTrialPoints(self, *args):
        r"""
        GetTrialPoints(self) -> itkVectorContainerULNPI3F
        GetTrialPoints(self) -> itkVectorContainerULNPI3F
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetTrialPoints(self, *args)

    def SetAlivePoints(self, _arg):
        r"""
        SetAlivePoints(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerULNPI3F *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_SetAlivePoints(self, _arg)

    def GetModifiableAlivePoints(self):
        r"""GetModifiableAlivePoints(self) -> itkVectorContainerULNPI3F"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetModifiableAlivePoints(self)

    def GetAlivePoints(self, *args):
        r"""
        GetAlivePoints(self) -> itkVectorContainerULNPI3F
        GetAlivePoints(self) -> itkVectorContainerULNPI3F
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetAlivePoints(self, *args)

    def SetProcessedPoints(self, _arg):
        r"""
        SetProcessedPoints(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerULNPI3F *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_SetProcessedPoints(self, _arg)

    def GetModifiableProcessedPoints(self):
        r"""GetModifiableProcessedPoints(self) -> itkVectorContainerULNPI3F"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetModifiableProcessedPoints(self)

    def GetProcessedPoints(self, *args):
        r"""
        GetProcessedPoints(self) -> itkVectorContainerULNPI3F
        GetProcessedPoints(self) -> itkVectorContainerULNPI3F
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetProcessedPoints(self, *args)

    def SetForbiddenPoints(self, _arg):
        r"""
        SetForbiddenPoints(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerULNPI3F *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_SetForbiddenPoints(self, _arg)

    def GetModifiableForbiddenPoints(self):
        r"""GetModifiableForbiddenPoints(self) -> itkVectorContainerULNPI3F"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetModifiableForbiddenPoints(self)

    def GetForbiddenPoints(self, *args):
        r"""
        GetForbiddenPoints(self) -> itkVectorContainerULNPI3F
        GetForbiddenPoints(self) -> itkVectorContainerULNPI3F
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetForbiddenPoints(self, *args)

    def SetStoppingCriterion(self, _arg):
        r"""
        SetStoppingCriterion(self, _arg)

        Parameters
        ----------
        _arg: itkFastMarchingStoppingCriterionBaseIF3IF3 *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_SetStoppingCriterion(self, _arg)

    def GetModifiableStoppingCriterion(self):
        r"""GetModifiableStoppingCriterion(self) -> itkFastMarchingStoppingCriterionBaseIF3IF3"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetModifiableStoppingCriterion(self)

    def GetStoppingCriterion(self, *args):
        r"""
        GetStoppingCriterion(self) -> itkFastMarchingStoppingCriterionBaseIF3IF3
        GetStoppingCriterion(self) -> itkFastMarchingStoppingCriterionBaseIF3IF3
        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetStoppingCriterion(self, *args)

    def GetSpeedConstant(self):
        r"""GetSpeedConstant(self) -> double"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetSpeedConstant(self)

    def SetSpeedConstant(self, _arg):
        r"""
        SetSpeedConstant(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_SetSpeedConstant(self, _arg)

    def GetNormalizationFactor(self):
        r"""GetNormalizationFactor(self) -> double"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetNormalizationFactor(self)

    def SetNormalizationFactor(self, _arg):
        r"""
        SetNormalizationFactor(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_SetNormalizationFactor(self, _arg)

    def GetTargetReachedValue(self):
        r"""GetTargetReachedValue(self) -> float"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetTargetReachedValue(self)

    def SetCollectPoints(self, _arg):
        r"""
        SetCollectPoints(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_SetCollectPoints(self, _arg)

    def GetCollectPoints(self):
        r"""GetCollectPoints(self) -> bool const &"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_GetCollectPoints(self)

    def CollectPointsOn(self):
        r"""CollectPointsOn(self)"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_CollectPointsOn(self)

    def CollectPointsOff(self):
        r"""CollectPointsOff(self)"""
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_CollectPointsOff(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkFastMarchingBaseIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingBaseIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_cast(obj)

# Register itkFastMarchingBaseIF3IF3 in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3_swigregister(itkFastMarchingBaseIF3IF3)
class itkFastMarchingTraitsEnums(object):
    r"""Proxy of C++ itkFastMarchingTraitsEnums class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    TopologyCheck_Nothing = _ITKFastMarchingBasePython.itkFastMarchingTraitsEnums_TopologyCheck_Nothing
    
    TopologyCheck_NoHandles = _ITKFastMarchingBasePython.itkFastMarchingTraitsEnums_TopologyCheck_NoHandles
    
    TopologyCheck_Strict = _ITKFastMarchingBasePython.itkFastMarchingTraitsEnums_TopologyCheck_Strict
    

    def __init__(self, *args):
        r"""
        __init__(self) -> itkFastMarchingTraitsEnums
        __init__(self, arg0) -> itkFastMarchingTraitsEnums

        Parameters
        ----------
        arg0: itkFastMarchingTraitsEnums const &

        """
        _ITKFastMarchingBasePython.itkFastMarchingTraitsEnums_swiginit(self, _ITKFastMarchingBasePython.new_itkFastMarchingTraitsEnums(*args))
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkFastMarchingTraitsEnums

# Register itkFastMarchingTraitsEnums in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkFastMarchingTraitsEnums_swigregister(itkFastMarchingTraitsEnums)

def itkVectorContainerUILSNF2_New():
    return itkVectorContainerUILSNF2.New()

class itkVectorContainerUILSNF2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerUILSNF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerUILSNF2_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerUILSNF2_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkLevelSetNodeF2,std::allocator< itkLevelSetNodeF2 > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkLevelSetNodeF2,std::allocator< itkLevelSetNodeF2 > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkLevelSetNodeF2

        Parameters
        ----------
        arg0: unsigned int

        ElementAt(self, arg0) -> itkLevelSetNodeF2

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkLevelSetNodeF2

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkLevelSetNodeF2

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeF2

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeF2

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeF2 *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerUILSNF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerUILSNF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerUILSNF2

        Create a new object of the class itkVectorContainerUILSNF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerUILSNF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerUILSNF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerUILSNF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerUILSNF2 in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerUILSNF2_swigregister(itkVectorContainerUILSNF2)

def itkVectorContainerUILSNF3_New():
    return itkVectorContainerUILSNF3.New()

class itkVectorContainerUILSNF3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerUILSNF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerUILSNF3_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerUILSNF3_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkLevelSetNodeF3,std::allocator< itkLevelSetNodeF3 > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkLevelSetNodeF3,std::allocator< itkLevelSetNodeF3 > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkLevelSetNodeF3

        Parameters
        ----------
        arg0: unsigned int

        ElementAt(self, arg0) -> itkLevelSetNodeF3

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkLevelSetNodeF3

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkLevelSetNodeF3

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeF3

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeF3

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeF3 *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerUILSNF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerUILSNF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerUILSNF3

        Create a new object of the class itkVectorContainerUILSNF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerUILSNF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerUILSNF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerUILSNF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerUILSNF3 in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerUILSNF3_swigregister(itkVectorContainerUILSNF3)

def itkVectorContainerUILSNSS2_New():
    return itkVectorContainerUILSNSS2.New()

class itkVectorContainerUILSNSS2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerUILSNSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerUILSNSS2_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerUILSNSS2_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkLevelSetNodeSS2,std::allocator< itkLevelSetNodeSS2 > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkLevelSetNodeSS2,std::allocator< itkLevelSetNodeSS2 > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkLevelSetNodeSS2

        Parameters
        ----------
        arg0: unsigned int

        ElementAt(self, arg0) -> itkLevelSetNodeSS2

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkLevelSetNodeSS2

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkLevelSetNodeSS2

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeSS2

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeSS2

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeSS2 *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerUILSNSS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerUILSNSS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerUILSNSS2

        Create a new object of the class itkVectorContainerUILSNSS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerUILSNSS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerUILSNSS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerUILSNSS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerUILSNSS2 in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerUILSNSS2_swigregister(itkVectorContainerUILSNSS2)

def itkVectorContainerUILSNSS3_New():
    return itkVectorContainerUILSNSS3.New()

class itkVectorContainerUILSNSS3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerUILSNSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerUILSNSS3_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerUILSNSS3_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkLevelSetNodeSS3,std::allocator< itkLevelSetNodeSS3 > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkLevelSetNodeSS3,std::allocator< itkLevelSetNodeSS3 > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkLevelSetNodeSS3

        Parameters
        ----------
        arg0: unsigned int

        ElementAt(self, arg0) -> itkLevelSetNodeSS3

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkLevelSetNodeSS3

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkLevelSetNodeSS3

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeSS3

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeSS3

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeSS3 *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerUILSNSS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerUILSNSS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerUILSNSS3

        Create a new object of the class itkVectorContainerUILSNSS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerUILSNSS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerUILSNSS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerUILSNSS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerUILSNSS3 in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerUILSNSS3_swigregister(itkVectorContainerUILSNSS3)

def itkVectorContainerUILSNUC2_New():
    return itkVectorContainerUILSNUC2.New()

class itkVectorContainerUILSNUC2(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerUILSNUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerUILSNUC2_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerUILSNUC2_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkLevelSetNodeUC2,std::allocator< itkLevelSetNodeUC2 > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkLevelSetNodeUC2,std::allocator< itkLevelSetNodeUC2 > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkLevelSetNodeUC2

        Parameters
        ----------
        arg0: unsigned int

        ElementAt(self, arg0) -> itkLevelSetNodeUC2

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkLevelSetNodeUC2

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkLevelSetNodeUC2

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeUC2

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeUC2

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeUC2 *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerUILSNUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerUILSNUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerUILSNUC2

        Create a new object of the class itkVectorContainerUILSNUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerUILSNUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerUILSNUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerUILSNUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerUILSNUC2 in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerUILSNUC2_swigregister(itkVectorContainerUILSNUC2)

def itkVectorContainerUILSNUC3_New():
    return itkVectorContainerUILSNUC3.New()

class itkVectorContainerUILSNUC3(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerUILSNUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerUILSNUC3_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerUILSNUC3_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkLevelSetNodeUC3,std::allocator< itkLevelSetNodeUC3 > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkLevelSetNodeUC3,std::allocator< itkLevelSetNodeUC3 > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkLevelSetNodeUC3

        Parameters
        ----------
        arg0: unsigned int

        ElementAt(self, arg0) -> itkLevelSetNodeUC3

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkLevelSetNodeUC3

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkLevelSetNodeUC3

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeUC3

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeUC3

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned int
        arg1: itkLevelSetNodeUC3 *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerUILSNUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerUILSNUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerUILSNUC3

        Create a new object of the class itkVectorContainerUILSNUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerUILSNUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerUILSNUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerUILSNUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerUILSNUC3 in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerUILSNUC3_swigregister(itkVectorContainerUILSNUC3)

def itkVectorContainerULNPI2F_New():
    return itkVectorContainerULNPI2F.New()

class itkVectorContainerULNPI2F(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerULNPI2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerULNPI2F_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerULNPI2F_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkNodePairI2F,std::allocator< itkNodePairI2F > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkNodePairI2F,std::allocator< itkNodePairI2F > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkNodePairI2F

        Parameters
        ----------
        arg0: unsigned long

        ElementAt(self, arg0) -> itkNodePairI2F

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkNodePairI2F

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkNodePairI2F

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI2F

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI2F

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI2F *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerULNPI2F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerULNPI2F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerULNPI2F

        Create a new object of the class itkVectorContainerULNPI2F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerULNPI2F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerULNPI2F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerULNPI2F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerULNPI2F in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerULNPI2F_swigregister(itkVectorContainerULNPI2F)

def itkVectorContainerULNPI2SS_New():
    return itkVectorContainerULNPI2SS.New()

class itkVectorContainerULNPI2SS(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerULNPI2SS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerULNPI2SS_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerULNPI2SS_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkNodePairI2SS,std::allocator< itkNodePairI2SS > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkNodePairI2SS,std::allocator< itkNodePairI2SS > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkNodePairI2SS

        Parameters
        ----------
        arg0: unsigned long

        ElementAt(self, arg0) -> itkNodePairI2SS

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkNodePairI2SS

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkNodePairI2SS

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI2SS

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI2SS

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI2SS *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerULNPI2SS

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerULNPI2SS

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerULNPI2SS

        Create a new object of the class itkVectorContainerULNPI2SS and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerULNPI2SS.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerULNPI2SS.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerULNPI2SS.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerULNPI2SS in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerULNPI2SS_swigregister(itkVectorContainerULNPI2SS)

def itkVectorContainerULNPI2UC_New():
    return itkVectorContainerULNPI2UC.New()

class itkVectorContainerULNPI2UC(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerULNPI2UC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerULNPI2UC_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerULNPI2UC_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkNodePairI2UC,std::allocator< itkNodePairI2UC > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkNodePairI2UC,std::allocator< itkNodePairI2UC > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkNodePairI2UC

        Parameters
        ----------
        arg0: unsigned long

        ElementAt(self, arg0) -> itkNodePairI2UC

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkNodePairI2UC

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkNodePairI2UC

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI2UC

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI2UC

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI2UC *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerULNPI2UC

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerULNPI2UC

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerULNPI2UC

        Create a new object of the class itkVectorContainerULNPI2UC and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerULNPI2UC.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerULNPI2UC.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerULNPI2UC.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerULNPI2UC in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerULNPI2UC_swigregister(itkVectorContainerULNPI2UC)

def itkVectorContainerULNPI3F_New():
    return itkVectorContainerULNPI3F.New()

class itkVectorContainerULNPI3F(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerULNPI3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerULNPI3F_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerULNPI3F_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkNodePairI3F,std::allocator< itkNodePairI3F > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkNodePairI3F,std::allocator< itkNodePairI3F > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkNodePairI3F

        Parameters
        ----------
        arg0: unsigned long

        ElementAt(self, arg0) -> itkNodePairI3F

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkNodePairI3F

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkNodePairI3F

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI3F

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI3F

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI3F *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerULNPI3F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerULNPI3F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerULNPI3F

        Create a new object of the class itkVectorContainerULNPI3F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerULNPI3F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerULNPI3F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerULNPI3F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerULNPI3F in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerULNPI3F_swigregister(itkVectorContainerULNPI3F)

def itkVectorContainerULNPI3SS_New():
    return itkVectorContainerULNPI3SS.New()

class itkVectorContainerULNPI3SS(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerULNPI3SS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerULNPI3SS_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerULNPI3SS_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkNodePairI3SS,std::allocator< itkNodePairI3SS > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkNodePairI3SS,std::allocator< itkNodePairI3SS > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkNodePairI3SS

        Parameters
        ----------
        arg0: unsigned long

        ElementAt(self, arg0) -> itkNodePairI3SS

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkNodePairI3SS

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkNodePairI3SS

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI3SS

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI3SS

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI3SS *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerULNPI3SS

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerULNPI3SS

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerULNPI3SS

        Create a new object of the class itkVectorContainerULNPI3SS and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerULNPI3SS.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerULNPI3SS.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerULNPI3SS.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerULNPI3SS in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerULNPI3SS_swigregister(itkVectorContainerULNPI3SS)

def itkVectorContainerULNPI3UC_New():
    return itkVectorContainerULNPI3UC.New()

class itkVectorContainerULNPI3UC(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkVectorContainerULNPI3UC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVectorContainerULNPI3UC_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVectorContainerULNPI3UC_Pointer"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::vector< itkNodePairI3UC,std::allocator< itkNodePairI3UC > > &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::vector< itkNodePairI3UC,std::allocator< itkNodePairI3UC > > const &"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkNodePairI3UC

        Parameters
        ----------
        arg0: unsigned long

        ElementAt(self, arg0) -> itkNodePairI3UC

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkNodePairI3UC

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkNodePairI3UC

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI3UC

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI3UC

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkNodePairI3UC *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_Initialize(self)
    __swig_destroy__ = _ITKFastMarchingBasePython.delete_itkVectorContainerULNPI3UC

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVectorContainerULNPI3UC

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVectorContainerULNPI3UC

        Create a new object of the class itkVectorContainerULNPI3UC and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVectorContainerULNPI3UC.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVectorContainerULNPI3UC.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVectorContainerULNPI3UC.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVectorContainerULNPI3UC in _ITKFastMarchingBasePython:
_ITKFastMarchingBasePython.itkVectorContainerULNPI3UC_swigregister(itkVectorContainerULNPI3UC)

